@@ -551,7 +551,7 @@ class Application(
 
     async def connect(
         self,
-        addr: Union[int, Callable[[], int], Awaitable[int]],
+        addr: Union[int, Callable[[], int], Callable[[], Awaitable[int]]],
         iv_index: int = 0,
         **kwargs,
     ) -> Mapping[int, Dict[Tuple[int, int], Dict[str, Tuple[Any, int]]]]:
@@ -570,12 +570,15 @@ class Application(
             configuration = await self.attach(**kwargs)
         except (ValueError, dbus_next.errors.DBusError) as ex:
             self.logger.error("Attach failed: %s, trying to import node", ex)
-            if isinstance(addr, Awaitable):
-                mesh_address = await addr
+
+            if isinstance(addr, int):
+                mesh_address = addr
             elif isinstance(addr, Callable):
                 mesh_address = addr()
-            elif isinstance(addr, int):
-                mesh_address = addr
+
+            if isinstance(addr, Awaitable):
+                mesh_address = await addr
+
             else:
                 raise TypeError(
                     "Address not given as a value or an acceptable callback."
