@@ -1,8 +1,35 @@
-from construct import Int8ul, Int16ul, Select, Struct, Switch, this, Embedded
+#
+# python-bluetooth-mesh - Bluetooth Mesh for Python
+#
+# Copyright (C) 2019  SILVAIR sp. z o.o.
+#
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+#
+#
 from enum import IntEnum
-from bluetooth_mesh.messages.util import EnumAdapter, Opcode
-from bluetooth_mesh.messages.generics import OptionalSetParameters, TransitionTimeAdapter, TransitionTime
+
+from construct import Embedded, Int8ul, Int16ul, Select, Struct, Switch, this
+
 from bluetooth_mesh.messages.config import StatusCodeAdapter
+from bluetooth_mesh.messages.generics import (
+    OptionalSetParameters,
+    TransitionTime,
+    TransitionTimeAdapter,
+)
+from bluetooth_mesh.messages.util import EnumAdapter, Opcode
 
 
 class LightCTLOpcode(IntEnum):
@@ -19,6 +46,9 @@ class LightCTLOpcode(IntEnum):
     CTL_TEMPERATURE_DEFAULT_GET = 0x8267
     CTL_TEMPERATURE_DEFAULT_STATUS = 0x8268
 
+    def __repr__(self):
+        return str(self.value)
+
 
 class LightCTLSetupOpcode(IntEnum):
     CTL_TEMPERATURE_DEFAULT_SET = 0x8269
@@ -26,7 +56,11 @@ class LightCTLSetupOpcode(IntEnum):
     CTL_TEMPERATURE_RANGE_SET = 0x826B
     CTL_TEMPERATURE_RANGE_SET_UNACKNOWLEDGED = 0x826C
 
+    def __repr__(self):
+        return str(self.value)
 
+
+# fmt: off
 LightCTLGet = Struct()
 
 LightCTLDefault = Struct(
@@ -112,7 +146,7 @@ LightCTLRangeStatus = Struct(
 
 
 LightCTLMessage = Struct(
-    "opcode" / EnumAdapter(Opcode, LightCTLOpcode),
+    "opcode" / Opcode(LightCTLOpcode),
     "params" / Switch(
         this.opcode,
         {
@@ -134,7 +168,7 @@ LightCTLMessage = Struct(
 
 
 LightCTLSetupMessage = Struct(
-    "opcode" / EnumAdapter(Opcode, LightCTLSetupOpcode),
+    "opcode" / Opcode(LightCTLSetupOpcode),
     "params" / Switch(
         this.opcode,
         {
@@ -145,3 +179,4 @@ LightCTLSetupMessage = Struct(
         },
     )
 )
+# fmt: on
